@@ -1,15 +1,18 @@
 import os
-from urllib import urlencode
+try:
+    from urllib import urlencode
+except ImportError:
+    from urllib.parse import urlencode
 
 import requests
 
 class OZCoreApi(object):
-    BASE_URL = os.environ['OZ_API_URL'] if os.environ.has_key('OZ_API_URL') else 'https://core.oz.com'
+    BASE_URL = os.environ['OZ_API_URL'] if 'OZ_API_URL' in os.environ else 'https://core.oz.com'
 
     def __init__(self, username, password):
         required_env = ['OZ_CLIENT_ID', 'OZ_CLIENT_SECRET']
         for var in required_env:
-            if not os.environ.has_key(var):
+            if not var in os.environ:
                 raise Exception('The required variable {0} was not set.'.format(var))
 
         self.client_id, self.client_secret = map(lambda var: os.environ[var], required_env)
@@ -48,6 +51,10 @@ class OZCoreApi(object):
                 **params)
         return self._fetch_object_at_uri(url)
 
+    def fetch_subtitles_by_video_id(self, video_id):
+        url = '{0}/channels/{1}/videos/{2}/subtitles'.format(self.BASE_URL, self.channel_id, video_id)
+        return self._fetch_object_at_uri(url)
+
     def create_collection(self, collection, **kwargs):
         url = self._append_query_params(
                 '{0}/channels/{1}/collections'.format(self.BASE_URL, self.channel_id),
@@ -66,6 +73,17 @@ class OZCoreApi(object):
                 **kwargs)
         return self._create_object_at_uri(video, url)
 
+    def create_subtitle(self, props, **kwargs):
+        uri = '{0}/channels/{1}/videos/{2}/subtitles'.format(self.BASE_URL, self.channel_id, props['videoId'])
+        r = requests.post(uri, data={'languageCode': props['languageCode']},
+                files={props['originalFileName']: props['subtitleData']},
+                headers={'Authorization': 'Bearer ' + self.access_token})
+        if r.status_code is 201:
+            return r.json()['data']
+        else:
+            raise Exception('an error occurred when creating object, status was: {0}\nError: {1}'
+                    .format(r.status_code, r.text))
+
     def update_collection(self, collection, **kwargs):
         url = self._append_query_params(
                 '{0}/channels/{1}/collections/{2}'.format(self.BASE_URL, self.channel_id, collection['id']),
